@@ -4,7 +4,6 @@
 # temporary access and token which are copied
 # in the aws credentials file under ./aws. These
 # credentials are then used to interact with AWS resources
-from aws_access_util.constants import constants
 import os.path
 import getpass
 import ast
@@ -17,6 +16,7 @@ import requests
 from bs4 import BeautifulSoup
 import sys
 sys.path.append('..')
+from aws_access_util.constants import constants # noqa: E402
 from aws_access_util.constants.constants import call_back_url  # noqa: E402
 from aws_access_util.constants.constants import awsconfigfile, \
     awsfolder  # noqa: E402
@@ -409,7 +409,7 @@ def get_aws_access(url, user, password, duration_seconds):
 if __name__ == "__main__":
 
     parser = argparse.ArgumentParser(
-        description="Retrives and stores a temporary token which is used to access AWS resource")
+        description="Retrieves and stores a temporary token which is used to access AWS resource")
     parser.add_argument('--awsurl',
                         dest='url',
                         type=str,
